CausalEstimand
==============

.. currentmodule:: pqp.identification

.. autoclass:: CausalEstimand
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CausalEstimand.expression

   .. rubric:: Methods Documentation

   .. automethod:: expression
